==> haskell-enclosed-exceptions-1.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW
key: enclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: 7a398a87e93ccc2c1fcded9e16edc174
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-9lY4zNxYanG1uBO73DvhGW
depends:
    base-4.11.1.0 transformers-0.5.5.0
    lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM
    monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX deepseq-1.4.3.0
    transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             lifted-base-0.2.3.12-4z1u4fqVS2e1krf2z3g8tM=d7abf1639edb70a4973bc923dc291932
             monad-control-1.0.2.3-4ughhLHj9Ka6p4m5wwuexX=ccfd06c57089143c2e021ca11cc4fff5
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             transformers-base-0.4.5.2-CPMQOTuCPA6G978LVAIlzh=24d243b13204b0d99b0f7fc5f56cecfb
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: enclosed-exceptions
version: 1.0.3
id: enclosed-exceptions-1.0.3-eFKerUBTsn9TNUbFs0Jp2
key: enclosed-exceptions-1.0.3-eFKerUBTsn9TNUbFs0Jp2
license: MIT
maintainer: jmacristovao@gmail.com, michael@snoyman.com
author: Michael Snoyman, João Cristóvão
homepage: https://github.com/jcristovao/enclosed-exceptions
synopsis: Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>
category: Control
abi: b78bd6c3c0fc7cc27129e4e533f958e8
exposed: True
exposed-modules:
    Control.Exception.Enclosed
import-dirs: /usr/lib/ghc-8.6.1/site-local/enclosed-exceptions-1.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/enclosed-exceptions-1.0.3
hs-libraries: HSenclosed-exceptions-1.0.3-eFKerUBTsn9TNUbFs0Jp2
depends:
    base-4.12.0.0 deepseq-1.4.4.0
    lifted-base-0.2.3.12-KjF0X1vOMmEKx0umQAcDw
    monad-control-1.0.2.3-GTHTd3ANl4bLcDnP0abGmh transformers-0.5.5.0
    transformers-base-0.4.5.2-IJREwika6Q09fUjnypf1lr
haddock-interfaces: /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock
haddock-html: /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
